#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2010 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Runtime.Serialization;
using HeuristicLab.Common;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Hive.Contracts.BusinessObjects {
  [StorableClass]
  [DataContract]
  [Serializable]
  public class SlaveDto : ResourceDto {
    [Storable]
    [DataMember]
    public int? NrOfCores { get; set; }
    [Storable]
    [DataMember]
    public int? NrOfFreeCores { get; set; }
    [Storable]
    [DataMember]
    public int? CpuSpeedPerCore { get; set; }
    [Storable]
    [DataMember]
    public int? Memory { get; set; }
    [Storable]
    [DataMember]
    public int? FreeMemory { get; set; }
    [Storable]
    [DataMember]
    public DateTime? Login { get; set; }
    [Storable]
    [DataMember]
    public SlaveState State { get; set; }
    [Storable]
    [DataMember]
    public CalendarState CalendarSyncStatus { get; set; }
    [Storable]
    [DataMember]
    public SlaveConfigDto Config { get; set; }
    [Storable]
    [DataMember]
    public bool IsAllowedToCalculate { get; set; }

    public SlaveDto() { }
    [StorableConstructor]
    protected SlaveDto(bool deserializing) : base(deserializing) { }
    protected SlaveDto(SlaveDto original, Cloner cloner)
      : base(original, cloner) {
      this.CalendarSyncStatus = original.CalendarSyncStatus;
      this.Config = cloner.Clone(original.Config);
      this.CpuSpeedPerCore = original.CpuSpeedPerCore;
      this.FreeMemory = original.FreeMemory;
      this.Login = original.Login;
      this.Memory = original.Memory;
      this.NrOfCores = original.NrOfCores;
      this.NrOfFreeCores = original.NrOfFreeCores;
      this.State = original.State;
      this.IsAllowedToCalculate = original.IsAllowedToCalculate;
    }
    public override IDeepCloneable Clone(Cloner cloner) {
      return new SlaveDto(this, cloner);
    }

    public override string ToString() {
      return base.ToString() + ", NrOfCores: " + NrOfCores + ", NrOfFreeCores " + NrOfFreeCores + ", Login: " + Login + ", State: " + State;
    }
  }
}
